@@ -1,14 +1,14 @@
 /** @file
 	Parser: Charset connection decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_CHARSET_H
 #define PA_CHARSET_H
 
-#define IDENT_PA_CHARSET_H "$Id: pa_charset.h,v 1.56 2020/12/15 17:10:30 moko Exp $"
+#define IDENT_PA_CHARSET_H "$Id: pa_charset.h,v 1.60 2024/12/11 21:57:35 moko Exp $"
 
 
 #include "pa_exception.h"
@@ -16,11 +16,16 @@
 #include "pa_hash.h"
 #include "pa_array.h"
 
-#include "pcre.h"
+#ifdef HAVE_PCRE2
+#include <pcre2.h>
+#else
+#include <pcre.h>
+#endif
 // we are using some pcre_internal.h stuff as well
 #include "../lib/pcre/pa_pcre_internal.h"
 
 #ifdef XML
+#include "libxml/xmlstring.h"
 #include "libxml/encoding.h"
 #endif
 
