@@ -1,14 +1,14 @@
 /** @file
 	Parser: commonly used functions.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_COMMON_H
 #define PA_COMMON_H
 
-#define IDENT_PA_COMMON_H "$Id: pa_common.h,v 1.189 2020/12/20 20:45:24 moko Exp $"
+#define IDENT_PA_COMMON_H "$Id: pa_common.h,v 1.196 2024/12/23 18:30:55 moko Exp $"
 
 #include "pa_string.h"
 #include "pa_hash.h"
@@ -38,7 +38,7 @@ class Request;
 #define HTTP_CONTENT_TYPE_MULTIPART_RELATED	"multipart/related"
 #define HTTP_CONTENT_TYPE_MULTIPART_MIXED	"multipart/mixed"
 
-const String content_disposition_filename_name(CONTENT_DISPOSITION_FILENAME_NAME);
+extern const String content_disposition_filename_name;
 
 #define HASH_ORDER
 
@@ -99,7 +99,7 @@ FILE *pa_fopen(const char *pathname, const char *mode);
 	file related functions
 */
 
-#define FILE_BUFFER_SIZE	4096
+#define FILE_BUFFER_SIZE (128*0x400)
 
 int pa_lock_shared_blocking(int fd);
 int pa_lock_exclusive_blocking(int fd);
@@ -227,7 +227,7 @@ char *lsplit(char *string, char delim);
 char *lsplit(char **string_ref,char delim);
 char *rsplit(char *string, char delim);
 
-const char* format(double value, const char *fmt);
+const char* format_double(double value, const char *fmt);
 
 char* unescape_chars(const char* cp, int len, Charset* client_charset=0, bool js=false/*true==decode \uXXXX and don't convert '+' to space*/);
 
@@ -243,11 +243,12 @@ void back_slashes_to_slashes(char *s);
 
 size_t strpos(const char *str, const char *substr);
 
-int remove_crlf(char *start, char *end);
+size_t remove_crlf(char *start, char *end);
 
 inline bool pa_isalpha(unsigned char c) { return (((c>='A') && (c<='Z')) || ((c>='a') && (c<='z'))); }
 inline bool pa_isalnum(unsigned char c) { return (((c>='0') && (c<='9')) || pa_isalpha(c)); }
 
+void pa_strncpy(char *dst, const char *src, size_t n);
 char *pa_strcat(const char *a, const char *b, const char *c = 0);
 const char *pa_filename(const char *path);
 
