@@ -1,14 +1,14 @@
 /** @file
 	Parser: Configure file for autoconf-disabled platforms.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_CONFIG_FIXED_H
 #define PA_CONFIG_FIXED_H
 
-#define IDENT_PA_CONFIG_FIXED_H "$Id: pa_config_fixed.h,v 1.91 2020/12/29 09:13:40 moko Exp $"
+#define IDENT_PA_CONFIG_FIXED_H "$Id: pa_config_fixed.h,v 1.94 2024/11/04 18:18:05 moko Exp $"
 
 #if _MSC_VER < 1310
 #define inline  __inline
@@ -34,7 +34,6 @@
 #define HAVE_FCNTL_H
 #define HAVE_IO_H
 #define HAVE_SYS_LOCKING_H
-#define HAVE__LOCKING
 
 #define HAVE_WINSOCK_H
 #define HAVE_TLS 1
