@@ -1,8 +1,8 @@
 /** @file
 	Parser: includes all Configure-d headers
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 
 	when used Configure [HAVE_CONFIG_H] it uses defines from Configure,
 	fixed otherwise.
@@ -165,6 +165,10 @@
 # endif
 #endif
 
+#ifdef HAVE_PCRE2
+#define PCRE2_CODE_UNIT_WIDTH 8
+#endif
+
 // math function replacements
 
 #ifdef __cplusplus
@@ -182,10 +186,10 @@ inline double sign(double param) { return param > 0 ? 1 : ( param < 0 ? -1 : 0 )
 #endif
 
 #if !defined(max)
-inline int max(int a, int b) { return a>b?a:b; }
-inline int min(int a, int b){ return a<b?a:b; }
-inline size_t max(size_t a, size_t b) { return a>b?a:b; }
-inline size_t min(size_t a, size_t b){ return a<b?a:b; }
+inline int max(int a, int b) { return a>b ? a : b; }
+inline int min(int a, int b){ return a<b ? a : b; }
+inline size_t max(size_t a, size_t b) { return a>b ? a : b; }
+inline size_t min(size_t a, size_t b){ return a<b ? a : b; }
 #endif
 
 #endif // __cplusplus
@@ -214,12 +218,12 @@ inline size_t min(size_t a, size_t b){ return a<b?a:b; }
 
 
 #ifdef __GNUC__
-#  define PA_ATTR_UNUSED __attribute__((unused))
+#  define PA_UNUSED __attribute__((unused))
 #else
-#  define PA_ATTR_UNUSED
+#  define PA_UNUSED
 #endif
 
-#ifdef WIN32
+#ifdef _MSC_VER
 #define THREAD_LOCAL __declspec(thread)
 #else
 #ifdef HAVE_TLS
@@ -229,13 +233,18 @@ inline size_t min(size_t a, size_t b){ return a<b?a:b; }
 #endif
 #endif
 
+#if defined(XML) && defined(__CYGWIN__)
+// otherwise functions in libxml2 will be declared as __declspec(dllimport)
+#define LIBXML_STATIC
+// to compile static libxslt.a and and libexslt.a, define LIBXSLT_STATIC in xsltexports.h and LIBEXSLT_STATIC in exsltexports.h
+#endif
+
 #ifdef __clang__
 #pragma clang diagnostic ignored "-Wparentheses"         // if(a=b)
 #pragma clang diagnostic ignored "-Wpointer-sign"        // CORD (unsigned char *) to char * in libcord
 #pragma clang diagnostic ignored "-Winline-new-delete"   // test for regular new/delete usage in memory.h
-#pragma clang diagnostic ignored "-Wdeprecated-register" // 'register' specifier is deprecated and incompatible with C++17
 
-#elif defined(__GNUC__)
+#elif defined(__GNUC__) && (__GNUC__ >= 7)
 #pragma GCC diagnostic ignored "-Wimplicit-fallthrough"  // case without break
 
 #endif
