@@ -1,14 +1,14 @@
 /** @file
 	Parser: directory scanning for different OS-es decls.
 
-	Copyright (c) 2000-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2000-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_DIR_H
 #define PA_DIR_H
 
-#define IDENT_PA_DIR_H "$Id: pa_dir.h,v 1.30 2020/12/15 17:10:31 moko Exp $"
+#define IDENT_PA_DIR_H "$Id: pa_dir.h,v 1.33 2024/11/04 03:53:25 moko Exp $"
 
 #include "pa_config_includes.h"
 
@@ -21,7 +21,7 @@
 
 #include <windows.h>
 
-#define MAXPATH MAX_PATH
+#define MAXPATH ((MAX_PATH)*2) /*UTF-16*/
 
 struct ffblk {
 	struct _WIN32_FIND_DATAW stat;
