@@ -1,14 +1,14 @@
 /** @file
 	Parser: exception decls.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_EXCEPTION_H
 #define PA_EXCEPTION_H
 
-#define IDENT_PA_EXCEPTION_H "$Id: pa_exception.h,v 1.68 2020/12/15 17:10:31 moko Exp $"
+#define IDENT_PA_EXCEPTION_H "$Id: pa_exception.h,v 1.75 2024/12/11 03:22:23 moko Exp $"
 
 const char* const PARSER_RUNTIME = "parser.runtime";
 const char* const IMAGE_FORMAT = "image.format";
@@ -18,16 +18,16 @@ const char* const BASE64_FORMAT = "base64.format";
 
 const char* const NAME_MUST_BE_STRING = "name must be string";
 const char* const FILE_NAME_MUST_BE_STRING = "file name must be string";
+const char* const FILE_NAME_MUST_BE_STRING_OR_FILE = "file name must be string or file";
+const char* const FILE_NAME_MUST_BE_NE_STRING = "file name must be not empty string";
 const char* const VALUE_MUST_BE_STRING = "value must be string";
 const char* const PARAMETER_MUST_BE_STRING = "parameter must be string";
 const char* const COLUMN_NAME_MUST_BE_STRING = "column name must be string";
 
 const char* const FILE_NAME_MUST_BE_SPECIFIED = "file name must be specified";
-const char* const FILE_NAME_MUST_NOT_BE_CODE = "file name must not be code";
-const char* const FIRST_ARG_MUST_NOT_BE_CODE = "first argument must not be code";
 const char* const PARAM_MUST_NOT_BE_CODE = "param must not be code";
 const char* const PARAM_MUST_BE_HASH = "param must be hash";
-const char* const MODE_MUST_NOT_BE_CODE = "mode must not be code";
+const char* const MODE_MUST_BE_STRING = "mode must be string";
 const char* const OPTIONS_MUST_NOT_BE_CODE = "options must not be code";
 
 const char* const CALLED_WITH_INVALID_OPTION = "called with invalid option";
