@@ -1,9 +1,9 @@
 /** @file
 	Parser: compiled code related decls.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
 
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef OPCODE_H
@@ -11,7 +11,7 @@
 
 namespace OP {
 
-#define IDENT_PA_OPCODE_H "$Id: pa_opcode.h,v 1.56 2020/12/15 17:10:31 moko Exp $"
+#define IDENT_PA_OPCODE_H "$Id: pa_opcode.h,v 1.59 2024/11/04 03:53:25 moko Exp $"
 
 #define OPTIMIZE_BYTECODE_GET_ELEMENT                // $a ^a
 #define OPTIMIZE_BYTECODE_GET_OBJECT_ELEMENT         // $a.b ^a.b
@@ -42,7 +42,7 @@ enum OPCODE {
 	/// @name actions
 	OP_WITH_ROOT,	OP_WITH_SELF,	OP_WITH_READ,	OP_WITH_WRITE,
 	OP_VALUE__GET_CLASS, OP_VALUE__GET_BASE_CLASS,
-	OP_CONSTRUCT_VALUE, OP_CONSTRUCT_EXPR, OP_CURLY_CODE__CONSTRUCT,
+	OP_CONSTRUCT_VALUE, OP_CONSTRUCT_EXPR, OP_CURLY_CODE__CONSTRUCT, OP_CONSTRUCT_ARRAY,
 	OP_WRITE_VALUE,	OP_WRITE_EXPR_RESULT,	OP_STRING__WRITE,
 #ifdef OPTIMIZE_BYTECODE_GET_ELEMENT
 	OP_VALUE__GET_ELEMENT_OR_OPERATOR,
