@@ -1,14 +1,14 @@
 /** @file
 	Parser: request class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_REQUEST_H
 #define PA_REQUEST_H
 
-#define IDENT_PA_REQUEST_H "$Id: pa_request.h,v 1.261 2020/12/31 19:48:46 moko Exp $"
+#define IDENT_PA_REQUEST_H "$Id: pa_request.h,v 1.268 2024/11/04 03:53:25 moko Exp $"
 
 #include "pa_pool.h"
 #include "pa_hash.h"
@@ -56,7 +56,8 @@ class VStateless_class;
 class VConsole;
 
 extern int pa_loop_limit;
-extern int pa_execute_recoursion_limit;
+extern int pa_array_limit;
+extern int pa_execute_recursion_limit;
 extern int pa_httpd_timeout;
 extern size_t pa_file_size_limit;
 
@@ -66,6 +67,7 @@ class Request: public PA_Object {
 	friend class Temp_connection;
 	friend class Temp_request_self;
 	friend class Temp_value_element;
+	friend class Temp_recursion;
 	friend class Request_context_saver;
 	friend class Exception_trace;
 
@@ -125,11 +127,11 @@ private:
 		element_type bottom_value() { return get(bottom_index()); }
 
 		void clear() {
-			fused=fbottom=0;
+			fsize=fbottom=0;
 		}
 
 		bool is_empty() {
-			return fused==fbottom;
+			return fsize==fbottom;
 		}
 
 		Table &table(Request &r);
@@ -147,7 +149,7 @@ private:
 	Array<String::Body> file_list;
 
 	/// endless execute(execute(... preventing counter
-	int anti_endless_execute_recoursion;
+	int anti_endless_execute_recursion;
 
 	///@}
 
@@ -210,6 +212,7 @@ public:
 	VStateless_class* get_class(const String& name);
 	VStateless_class& get_class_ref(const String& name);
 	void put_class(VStateless_class *aclass){ classes().put(aclass->type(), aclass); }
+	bool add_class(const char* atype, VStateless_class *aclass);
 
 	/**
 		core request processing
@@ -248,14 +251,14 @@ public:
 
 	Value& construct(VStateless_class &class_value, const Method &method);
 
-	/// execute ops with anti-recoursion check
-	void recoursion_checked_execute(ArrayOperation& ops) {
-		if(++anti_endless_execute_recoursion==pa_execute_recoursion_limit) {
-			anti_endless_execute_recoursion=0; // give @exception a chance
+	/// execute ops with anti-recursion check
+	void recursion_checked_execute(ArrayOperation& ops) {
+		if(++anti_endless_execute_recursion==pa_execute_recursion_limit) {
+			anti_endless_execute_recursion=0; // give @exception a chance
 			throw Exception(PARSER_RUNTIME, 0, "call canceled - endless recursion detected");
 		}
 		execute(ops); // execute it
-		anti_endless_execute_recoursion--;
+		anti_endless_execute_recursion--;
 	}
 
 	///
@@ -369,6 +372,7 @@ public: // status read methods
 
 	//{ for @conf[filespec] and @auto[filespec]
 	bool execute_method_if_exists(VStateless_class& aclass, const String& method_name, Value* optional_param);
+	bool execute_auto_method_if_exists(VStateless_class& aclass, const String& method_name, Value* optional_param);
 
 	//}
 
@@ -438,7 +442,7 @@ class Request_context_saver {
 	size_t exception_trace_bottom;
 	/// execution stack
 	size_t stack;
-	uint anti_endless_execute_recoursion;
+	uint anti_endless_execute_recursion;
 	/// contexts
 	VMethodFrame* method_frame;
 	Value* rcontext;
@@ -454,7 +458,7 @@ public:
 		exception_trace_top(ar.exception_trace.top_index()),
 		exception_trace_bottom(ar.exception_trace.bottom_index()),
 		stack(ar.stack.top_index()),
-		anti_endless_execute_recoursion(ar.anti_endless_execute_recoursion),
+		anti_endless_execute_recursion(ar.anti_endless_execute_recursion),
 		method_frame(ar.method_frame),
 		rcontext(ar.rcontext),
 		wcontext(ar.wcontext),
@@ -464,7 +468,7 @@ public:
 		fr.exception_trace.set_top_index(exception_trace_top);
 		fr.exception_trace.set_bottom_index(exception_trace_bottom);
 		fr.stack.set_top_index(stack);
-		fr.anti_endless_execute_recoursion=anti_endless_execute_recoursion;
+		fr.anti_endless_execute_recursion=anti_endless_execute_recursion;
 		fr.method_frame=method_frame, fr.rcontext=rcontext; fr.wcontext=wcontext;
 		fr.flang=flang;
 		fr.fconnection=fconnection;
@@ -537,4 +541,16 @@ public:
 	~Temp_value_element();
 };
 
+///	Auto-object that temporarily increases recursion
+class Temp_recursion {
+	Request& frequest;
+public:
+	Temp_recursion(Request& arequest) : frequest(arequest){
+		frequest.anti_endless_execute_recursion++;
+	}
+	~Temp_recursion(){
+		frequest.anti_endless_execute_recursion--;
+	}
+};
+
 #endif
