@@ -1,14 +1,14 @@
 /** @file
 	Parser: string class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_STRING_H
 #define PA_STRING_H
 
-#define IDENT_PA_STRING_H "$Id: pa_string.h,v 1.228 2020/12/15 17:10:32 moko Exp $"
+#define IDENT_PA_STRING_H "$Id: pa_string.h,v 1.234 2024/11/04 03:53:25 moko Exp $"
 
 // includes
 #include "pa_types.h"
@@ -47,12 +47,31 @@ class SQL_Connection;
 class Dictionary;
 class Request_charsets;
 class String;
-typedef Array<const String*> ArrayString;
 class VRegex;
 
+#ifdef NDEBUG
+typedef Array<const String*> ArrayString;
+#else
+class ArrayString : public Array<const String*> {
+public:
+	inline ArrayString(size_t initial=0) : Array(initial){
+	}
+	inline Array& operator+=(element_type src) {
+		assert(src != NULL);
+		return Array::operator+=(src);
+	}
+
+	inline element_type get(size_t index) const {
+		element_type result=Array::get(index);
+		assert(result != NULL);
+		return result;
+	}
+};
+#endif
+
 // generally useful
 
-double pa_atod(const char* str, const String* problem_source=0);
+double pa_atod(const char* str, const String* problem_source);
 int pa_atoi(const char* str, int base=10, const String* problem_source=0);
 unsigned int pa_atoui(const char *str, int base=10, const String* problem_source=0);
 uint64_t pa_atoul(const char *str, int base=10, const String* problem_source=0);
@@ -382,8 +401,6 @@ public:
 		}
 
 
-		static Body Format(int value);
-
 		void clear() { ZERO_LENGTH ZERO_HASH_CODE body=CORD_EMPTY; }
 
 		bool operator! () const { return is_empty(); }
