@@ -1,14 +1,14 @@
 /** @file
 	Parser: generally used types & constants decls.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_TYPES_H
 #define PA_TYPES_H
 
-#define IDENT_PA_TYPES_H "$Id: pa_types.h,v 1.55 2020/12/15 17:10:32 moko Exp $"
+#define IDENT_PA_TYPES_H "$Id: pa_types.h,v 1.59 2024/11/04 03:53:25 moko Exp $"
 
 #include "pa_config_includes.h"
 
@@ -41,16 +41,17 @@ typedef unsigned long ulong;
 #define ULLONG_MAX 18446744073709551615ULL
 #endif
 
-#ifndef INT32_MAX
-#define INT32_MAX 2147483647L
-#endif
-
-#ifndef UINT32_MAX
-#define UINT32_MAX 4294967295UL
-#endif
-
 #ifndef SSIZE_MAX
-#define SSIZE_MAX (sizeof(size_t)==4 ? INT32_MAX : LLONG_MAX)
+#define SSIZE_MAX (sizeof(size_t)==4 ? INT_MAX : LLONG_MAX)
 #endif
 
+inline int clip2int(double value) {
+	return value <= INT_MIN ? INT_MIN : ( value >= INT_MAX ? INT_MAX : (int)value );
+}
+
+inline uint clip2uint(double value) {
+	return value <= 0 ? 0 : ( value >= UINT_MAX ? UINT_MAX : (uint)value );
+}
+
+
 #endif
