@@ -15,8 +15,7 @@
 /* Boehm, October 3, 1994 5:19 pm PDT */
 
 #include "pa_config_includes.h"
-#include "gc.h"
-#include "cord.h"
+#include "include/cord.h"
 
 /* An implementation of the cord primitives.  These are the only 	*/
 /* Functions that understand the representation.  We perform only	*/
