@@ -20,7 +20,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: curl.h,v 1.4 2013/04/28 21:28:43 moko Exp $
+ * $Id: curl.h,v 1.5 2017/11/26 21:24:07 moko Exp $
  ***************************************************************************/
 
 /*
@@ -838,49 +838,66 @@ typedef enum {
 #define CURLINFO_LONG     0x200000
 #define CURLINFO_DOUBLE   0x300000
 #define CURLINFO_SLIST    0x400000
+#define CURLINFO_PTR      0x400000 /* same as SLIST */
+#define CURLINFO_SOCKET   0x500000
+#define CURLINFO_OFF_T    0x600000
 #define CURLINFO_MASK     0x0fffff
 #define CURLINFO_TYPEMASK 0xf00000
 
 typedef enum {
-  CURLINFO_NONE, /* first, never use this */
-  CURLINFO_EFFECTIVE_URL    = CURLINFO_STRING + 1,
-  CURLINFO_RESPONSE_CODE    = CURLINFO_LONG   + 2,
-  CURLINFO_TOTAL_TIME       = CURLINFO_DOUBLE + 3,
-  CURLINFO_NAMELOOKUP_TIME  = CURLINFO_DOUBLE + 4,
-  CURLINFO_CONNECT_TIME     = CURLINFO_DOUBLE + 5,
-  CURLINFO_PRETRANSFER_TIME = CURLINFO_DOUBLE + 6,
-  CURLINFO_SIZE_UPLOAD      = CURLINFO_DOUBLE + 7,
-  CURLINFO_SIZE_DOWNLOAD    = CURLINFO_DOUBLE + 8,
-  CURLINFO_SPEED_DOWNLOAD   = CURLINFO_DOUBLE + 9,
-  CURLINFO_SPEED_UPLOAD     = CURLINFO_DOUBLE + 10,
-  CURLINFO_HEADER_SIZE      = CURLINFO_LONG   + 11,
-  CURLINFO_REQUEST_SIZE     = CURLINFO_LONG   + 12,
-  CURLINFO_SSL_VERIFYRESULT = CURLINFO_LONG   + 13,
-  CURLINFO_FILETIME         = CURLINFO_LONG   + 14,
-  CURLINFO_CONTENT_LENGTH_DOWNLOAD   = CURLINFO_DOUBLE + 15,
-  CURLINFO_CONTENT_LENGTH_UPLOAD     = CURLINFO_DOUBLE + 16,
-  CURLINFO_STARTTRANSFER_TIME = CURLINFO_DOUBLE + 17,
-  CURLINFO_CONTENT_TYPE     = CURLINFO_STRING + 18,
-  CURLINFO_REDIRECT_TIME    = CURLINFO_DOUBLE + 19,
-  CURLINFO_REDIRECT_COUNT   = CURLINFO_LONG   + 20,
-  CURLINFO_PRIVATE          = CURLINFO_STRING + 21,
-  CURLINFO_HTTP_CONNECTCODE = CURLINFO_LONG   + 22,
-  CURLINFO_HTTPAUTH_AVAIL   = CURLINFO_LONG   + 23,
-  CURLINFO_PROXYAUTH_AVAIL  = CURLINFO_LONG   + 24,
-  CURLINFO_OS_ERRNO         = CURLINFO_LONG   + 25,
-  CURLINFO_NUM_CONNECTS     = CURLINFO_LONG   + 26,
-  CURLINFO_SSL_ENGINES      = CURLINFO_SLIST  + 27,
-  CURLINFO_COOKIELIST       = CURLINFO_SLIST  + 28,
-  CURLINFO_LASTSOCKET       = CURLINFO_LONG   + 29,
-  CURLINFO_FTP_ENTRY_PATH   = CURLINFO_STRING + 30,
-  CURLINFO_REDIRECT_URL     = CURLINFO_STRING + 31,
-  CURLINFO_PRIMARY_IP       = CURLINFO_STRING + 32,
-  CURLINFO_APPCONNECT_TIME  = CURLINFO_DOUBLE + 33,
-  CURLINFO_CERTINFO         = CURLINFO_SLIST  + 34,
-  CURLINFO_CONDITION_UNMET  = CURLINFO_LONG   + 35,
+  CURLINFO_NONE,                  /* first, never use this */
+  CURLINFO_EFFECTIVE_URL           = CURLINFO_STRING + 1,
+  CURLINFO_RESPONSE_CODE           = CURLINFO_LONG   + 2,
+  CURLINFO_TOTAL_TIME              = CURLINFO_DOUBLE + 3,
+  CURLINFO_NAMELOOKUP_TIME         = CURLINFO_DOUBLE + 4,
+  CURLINFO_CONNECT_TIME            = CURLINFO_DOUBLE + 5,
+  CURLINFO_PRETRANSFER_TIME        = CURLINFO_DOUBLE + 6,
+  CURLINFO_SIZE_UPLOAD             = CURLINFO_DOUBLE + 7,
+  CURLINFO_SIZE_DOWNLOAD           = CURLINFO_DOUBLE + 8,
+  CURLINFO_SPEED_DOWNLOAD          = CURLINFO_DOUBLE + 9,
+  CURLINFO_SPEED_UPLOAD            = CURLINFO_DOUBLE + 10,
+  CURLINFO_HEADER_SIZE             = CURLINFO_LONG   + 11,
+  CURLINFO_REQUEST_SIZE            = CURLINFO_LONG   + 12,
+  CURLINFO_SSL_VERIFYRESULT        = CURLINFO_LONG   + 13,
+  CURLINFO_FILETIME                = CURLINFO_LONG   + 14,
+  CURLINFO_CONTENT_LENGTH_DOWNLOAD = CURLINFO_DOUBLE + 15,
+  CURLINFO_CONTENT_LENGTH_UPLOAD   = CURLINFO_DOUBLE + 16,
+  CURLINFO_STARTTRANSFER_TIME      = CURLINFO_DOUBLE + 17,
+  CURLINFO_CONTENT_TYPE            = CURLINFO_STRING + 18,
+  CURLINFO_REDIRECT_TIME           = CURLINFO_DOUBLE + 19,
+  CURLINFO_REDIRECT_COUNT          = CURLINFO_LONG   + 20,
+  CURLINFO_PRIVATE                 = CURLINFO_STRING + 21,
+  CURLINFO_HTTP_CONNECTCODE        = CURLINFO_LONG   + 22,
+  CURLINFO_HTTPAUTH_AVAIL          = CURLINFO_LONG   + 23,
+  CURLINFO_PROXYAUTH_AVAIL         = CURLINFO_LONG   + 24,
+  CURLINFO_OS_ERRNO                = CURLINFO_LONG   + 25,
+  CURLINFO_NUM_CONNECTS            = CURLINFO_LONG   + 26,
+  CURLINFO_SSL_ENGINES             = CURLINFO_SLIST  + 27,
+  CURLINFO_COOKIELIST              = CURLINFO_SLIST  + 28,
+  CURLINFO_LASTSOCKET              = CURLINFO_LONG   + 29,
+  CURLINFO_FTP_ENTRY_PATH          = CURLINFO_STRING + 30,
+  CURLINFO_REDIRECT_URL            = CURLINFO_STRING + 31,
+  CURLINFO_PRIMARY_IP              = CURLINFO_STRING + 32,
+  CURLINFO_APPCONNECT_TIME         = CURLINFO_DOUBLE + 33,
+  CURLINFO_CERTINFO                = CURLINFO_SLIST  + 34,
+  CURLINFO_CONDITION_UNMET         = CURLINFO_LONG   + 35,
+  CURLINFO_RTSP_SESSION_ID         = CURLINFO_STRING + 36,
+  CURLINFO_RTSP_CLIENT_CSEQ        = CURLINFO_LONG   + 37,
+  CURLINFO_RTSP_SERVER_CSEQ        = CURLINFO_LONG   + 38,
+  CURLINFO_RTSP_CSEQ_RECV          = CURLINFO_LONG   + 39,
+  CURLINFO_PRIMARY_PORT            = CURLINFO_LONG   + 40,
+  CURLINFO_LOCAL_IP                = CURLINFO_STRING + 41,
+  CURLINFO_LOCAL_PORT              = CURLINFO_LONG   + 42,
+  CURLINFO_TLS_SESSION             = CURLINFO_PTR    + 43,
+  CURLINFO_ACTIVESOCKET            = CURLINFO_SOCKET + 44,
+  CURLINFO_TLS_SSL_PTR             = CURLINFO_PTR    + 45,
+  CURLINFO_HTTP_VERSION            = CURLINFO_LONG   + 46,
+  CURLINFO_PROXY_SSL_VERIFYRESULT  = CURLINFO_LONG   + 47,
+  CURLINFO_PROTOCOL                = CURLINFO_LONG   + 48,
+  CURLINFO_SCHEME                  = CURLINFO_STRING + 49,
   /* Fill in new entries below here! */
 
-  CURLINFO_LASTONE          = 35
+  CURLINFO_LASTONE                 = 49
 } CURLINFO;
 
 #define CURL_IPRESOLVE_WHATEVER 0 /* default, resolves addresses to all IP versions that your system allows */
@@ -902,4 +919,22 @@ typedef enum {
   CURL_FORMADD_LAST /* last */
 } CURLFORMcode;
 
+
+enum {
+  CURL_HTTP_VERSION_NONE,               /* setting this means we don't care, and that we'd
+                                           like the library to choose the best possible for us! */
+  CURL_HTTP_VERSION_1_0,                /* please use HTTP 1.0 in the request */
+  CURL_HTTP_VERSION_1_1,                /* please use HTTP 1.1 in the request */
+  CURL_HTTP_VERSION_2_0,                /* please use HTTP 2 in the request */
+  CURL_HTTP_VERSION_2TLS,               /* use version 2 for HTTPS, version 1.1 for HTTP */
+  CURL_HTTP_VERSION_2_PRIOR_KNOWLEDGE,  /* please use HTTP 2 without HTTP/1.1 Upgrade */
+
+  CURL_HTTP_VERSION_LAST                /* *ILLEGAL* http version */
+};
+
+/* Convenience definition simple because the name of the version is HTTP/2 and
+not 2.0. The 2_0 version of the enum name was set while the version was
+still planned to be 2.0 and we stick to it for compatibility. */
+#define CURL_HTTP_VERSION_2 CURL_HTTP_VERSION_2_0
+
 #endif /* __CURL_CURL_H */
