@@ -1,55 +1,17 @@
-/* ====================================================================
- * The Apache Software License, Version 1.1
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- * Copyright (c) 2000-2002 The Apache Software Foundation.  All rights
- * reserved.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Apache" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 #ifndef PA_FILE_IO_H
@@ -85,15 +47,9 @@ extern "C" {
 #define PA_BINARY     32          /**< Open the file in binary mode */
 #define PA_EXCL       64          /**< Open should fail if PA_CREATE and file
                                         exists. */
-#define PA_BUFFERED   128         /**< Open the file for buffered I/O */
-#define PA_DELONCLOSE 256         /**< Delete the file after close */
-#define PA_XTHREAD    512         /**< Platform dependent tag to open the file
-                                        for use across multiple threads */
 #define PA_SHARELOCK  1024        /**< Platform dependent support for higher
                                         level locked read/write access to support
                                         writes across process/machines */
-#define PA_FILE_NOCLEANUP  2048   /**< Do not register a cleanup when the file
-                                        is opened */
  
 /** @} */
 
@@ -135,8 +91,7 @@ typedef struct pa_file_t         pa_file_t;
                                            a "write lock". */
 
 #define PA_FLOCK_TYPEMASK      0x000F  /**< mask to extract lock type */
-#define PA_FLOCK_NONBLOCK      0x0010  /**< do not block while acquiring the
-                                           file lock */
+
 /** @} */
 
 /**
@@ -152,18 +107,10 @@ typedef struct pa_file_t         pa_file_t;
  *           PA_TRUNCATE         set length to zero if file exists
  *           PA_BINARY           not a text file (This flag is ignored on 
  *                                UNIX because it has no meaning)
- *           PA_BUFFERED         buffer the data.  Default is non-buffered
  *           PA_EXCL             return error if PA_CREATE and file exists
- *           PA_DELONCLOSE       delete the file after closing.
- *           PA_XTHREAD          Platform dependent tag to open the file
- *                                for use across multiple threads
  *           PA_SHARELOCK        Platform dependent support for higher
  *                                level locked read/write access to support
  *                                writes across process/machines
- *           PA_FILE_NOCLEANUP   Do not register a cleanup with the pool 
- *                                passed in on the <EM>cont</EM> argument (see below).
- *                                The pa_os_file_t handle in pa_file_t will not
- &                                be closed when the pool is destroyed.
  * </PRE>
  * @param perm Access permissions for file.
  * @param cont The pool to use.
