@@ -1,14 +1,14 @@
 /** @file
 	Parser: compiler support helper functions decls.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef COMPILE_TOOLS
 #define COMPILE_TOOLS
 
-#define IDENT_COMPILE_TOOLS_H "$Id: compile_tools.h,v 1.115 2020/12/15 17:10:34 moko Exp $"
+#define IDENT_COMPILE_TOOLS_H "$Id: compile_tools.h,v 1.121 2024/11/04 03:53:25 moko Exp $"
 
 #include "pa_opcode.h"
 #include "pa_types.h"
@@ -84,10 +84,11 @@ public:
 	bool in_call_value;
 	bool explicit_result;
 	bool append;
+	bool array;
 	//@}
 	
 	/// output: filled input 'methods' and 'error' if any
-	char error[MAX_STRING];
+	const char *error;
 
 	Parse_control(Request& arequest, 
 		VStateless_class* aclass,
@@ -114,12 +115,14 @@ public:
 		ls_sp(0),
 		in_call_value(false),
 		explicit_result(false),
-		append(false) {
+		append(false),
+		array(false),
+		error("") {
 
 		*cclasses+=aclass;
 	}
 
-	/// true if exception should be rised
+	/// false if exception should be rised
 	bool class_add(){
 		if(cclass_new){
 			cclass=cclass_new;
@@ -127,11 +130,9 @@ public:
 			cclass_new=0;
 			append=false;
 			// append to request's classes
-			if(!request.allow_class_replace)
-				return request.classes().put_dont_replace(cclass->type(), cclass) != 0;
-			request.classes().put(cclass->type(), cclass);
+			return request.add_class(cclass->type(), cclass);
 		}
-		return false;
+		return true;
 	}
 
 	VStateless_class* get_existed_class(VStateless_class* aclass){
