@@ -1,14 +1,14 @@
 /** @file
 	Parser: Method class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_METHOD_H
 #define PA_METHOD_H
 
-#define IDENT_PA_METHOD_H "$Id: pa_method.h,v 1.32 2020/12/15 17:10:38 moko Exp $"
+#define IDENT_PA_METHOD_H "$Id: pa_method.h,v 1.37 2024/12/10 02:40:53 moko Exp $"
 
 #define OPTIMIZE_CALL
 #define OPTIMIZE_RESULT
@@ -52,7 +52,7 @@ public:
 	};
 	
 	enum Result_optimization {
-		RO_UNKNOWN,
+		RO_UNKNOWN,    // during first parser method call, until $result detected on method ends.
 		RO_USE_RESULT, // write to $result detected, will not collect all writes to output scope.
 		RO_USE_WCONTEXT // native code or parser code without $result usage.
 	};
@@ -88,8 +88,9 @@ public:
 
 	mutable VJunction *junction_template;
 
-	const String *name; // method name, never null
-	const String *extra_params; // method has *name as an argument
+	const String* name; // method name, never null
+	const String* extra_params; // last argument uses the *name notation
+	ArrayString* named_params; // last arguments use the .name notation
 
 	Method(
 		Call_type acall_type,
@@ -125,9 +126,21 @@ public:
 					extra_params = new String(pa_strdup(last_param+1));
 					params_names->remove(--params_count);
 					return;
+				} else if (last_param[0] == '.' && last_param[1]){
+					named_params = new ArrayString(params_count);
+					do {
+						// local variables are not ordered, but direct order for reflection
+						named_params->insert(0, new String(pa_strdup(last_param+1)));
+						params_names->remove(--params_count);
+						if (!params_count)
+							break;
+						last_param = params_names->get(params_count-1)->cstr();
+					} while (last_param[0] == '.' && last_param[1]);
+					return;
 				}
 			}
 			extra_params = NULL;
+			named_params = NULL;
 	}
 
 	/// call this before invoking to ensure proper actual numbered params count
