@@ -1,14 +1,14 @@
 /** @file
 	Parser: Value, Method, Junction .
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VALUE_H
 #define PA_VALUE_H
 
-#define IDENT_PA_VALUE_H "$Id: pa_value.h,v 1.167 2020/12/15 17:10:38 moko Exp $"
+#define IDENT_PA_VALUE_H "$Id: pa_value.h,v 1.176 2024/11/04 03:53:25 moko Exp $"
 
 #include "pa_common.h"
 #include "pa_array.h"
@@ -32,7 +32,9 @@ class VMethodFrame;
 class VFile;
 class Table;
 struct XDocOutputOptions;
-typedef Array<Value*> ArrayValue;
+
+template <typename T>class SparseArray;
+typedef SparseArray<Value*> ArrayValue;
 
 struct Json_options : public PA_Allocated {
 	Request* r;
@@ -42,11 +44,12 @@ struct Json_options : public PA_Allocated {
 	Value* params;
 	bool skip_unknown;
 	bool one_line;
-	uint json_string_recoursion;
+	uint json_string_recursion;
 	const char* indent;
 	XDocOutputOptions* xdoc_options;
 	enum Date { D_SQL, D_GMT, D_ISO, D_TIMESTAMP } date;
 	enum Table { T_ARRAY, T_OBJECT, T_COMPACT } table;
+	enum Array { A_ARRAY, A_OBJECT, A_COMPACT } array;
 	enum File { F_BODYLESS, F_BASE64, F_TEXT } file;
 	enum Void { V_NULL, V_STRING } fvoid;
 
@@ -57,11 +60,12 @@ struct Json_options : public PA_Allocated {
 		params(NULL),
 		skip_unknown(false),
 		one_line(false),
-		json_string_recoursion(0),
+		json_string_recursion(0),
 		indent(NULL),
 		xdoc_options(NULL),
 		date(D_SQL),
 		table(T_OBJECT),
+		array(A_COMPACT),
 		file(F_BODYLESS),
 		fvoid(V_NULL)
 	{}
@@ -83,6 +87,14 @@ struct Json_options : public PA_Allocated {
 		return true;
 	}
 
+	bool set_array_format(const String &value){
+		if(value == "array") array = A_ARRAY;
+		else if (value == "object") array = A_OBJECT;
+		else if (value == "compact") array = A_COMPACT;
+		else return false;
+		return true;
+	}
+
 	bool set_file_format(const String &value){
 		if(value == "base64") file = F_BASE64;
 		else if (value == "text") file = F_TEXT;
@@ -99,6 +111,8 @@ struct Json_options : public PA_Allocated {
 	}
 
 	const String* hash_json_string(HashStringValue *hash);
+	const String* array_json_string(ArrayValue *array);
+	const String* array_compact_json_string(ArrayValue *array);
 };
 
 ///	grandfather of all @a values in @b Parser
@@ -109,15 +123,10 @@ public: // Value
 	virtual const char* type() const =0;
 
 	/**
-		all except VObject/VClass: this if @atype eq type()
+		all except VObject/VClass: true if @atype eq type()
 		VObject/VClass: can locate parent class by it's type
 	*/
-	virtual Value* as(const char* atype) {
-		return atype && strcmp(type(), atype)==0?this:0;
-	}
-
-	/// type checking helper, uses Value::as
-	bool is(const char* atype) { return as(atype)!=0; }
+	virtual bool is(const char* atype) { return atype && strcmp(type(), atype)==0; }
 
 	/// is this value defined?
 	virtual bool is_defined() const { return true; }
@@ -136,7 +145,7 @@ public: // Value
 
 	/// what's the meaning of this value in context of expression?
 	virtual Value& as_expr_result() {
-		return *bark("is '%s', can not be used in expression"); 
+		return *bark("is '%s', cannot be used in expression"); 
 	}
 
 	/** extract HashStringValue if any
@@ -165,7 +174,8 @@ public: // Value
 	virtual bool as_bool() const { bark("is '%s', it does not have logical value"); return 0; }
 
 	/// extract file
-	virtual VFile* as_vfile(String::Language lang, const Request_charsets* charsets=0);
+	virtual VFile* as_vfile();
+	virtual VFile* as_vfile(String::Language /*lang*/, const Request_charsets* /*charsets*/) { return as_vfile(); }
 
 	/// extract Junction
 	virtual Junction* get_junction();
@@ -186,7 +196,7 @@ public: // Value
 		// to prevent modification of system classes,
 		// created at system startup, and not having exception
 		// handler installed, we neet to bark using request.pool
-		bark("element can not be stored to %s", &aname); 
+		bark("element cannot be stored into %s", &aname); 
 		return 0;
 	}
 
