@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b bool class decls.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VBOOL_H
 #define PA_VBOOL_H
 
-#define IDENT_PA_VBOOL_H "$Id: pa_vbool.h,v 1.38 2020/12/15 17:10:39 moko Exp $"
+#define IDENT_PA_VBOOL_H "$Id: pa_vbool.h,v 1.41 2024/11/04 03:53:25 moko Exp $"
 
 // include
 
@@ -24,7 +24,7 @@
 extern Methoded* bool_class;
 
 // VBool
-class VBool: public VStateless_object {
+class VBool: public VSimple_stateless_object {
 public: // Value
 
 	override const char* type() const { return VBOOL_TYPE; }
