@@ -1,14 +1,14 @@
 /**	@file
 	Parser: @b class parser class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VCLASS_H
 #define PA_VCLASS_H
 
-#define IDENT_PA_VCLASS_H "$Id: pa_vclass.h,v 1.74 2021/01/02 23:01:11 moko Exp $"
+#define IDENT_PA_VCLASS_H "$Id: pa_vclass.h,v 1.77 2024/11/04 03:53:25 moko Exp $"
 
 #define OBJECT_PROTOTYPE
 #define CLASS_GETTER_UNPROTECTED
@@ -32,7 +32,7 @@ public: // Value
 
 	/// VClass: true
 	override bool as_bool() const { return true; }
-	override Value* as(const char* atype);
+	override bool is(const char* atype);
 
 	override Value* get_element(Value& aself, const String& aname);
 	override const VJunction* put_element(Value& self, const String& name, Value* value);
