@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b date parser class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VDATE_H
 #define PA_VDATE_H
 
-#define IDENT_PA_VDATE_H "$Id: pa_vdate.h,v 1.66 2020/12/15 17:10:39 moko Exp $"
+#define IDENT_PA_VDATE_H "$Id: pa_vdate.h,v 1.71 2024/11/04 03:53:25 moko Exp $"
 
 #include "classes.h"
 #include "pa_common.h"
@@ -50,7 +50,15 @@ public: // Value
 	override bool is_evaluated_expr() const { return true; }
 
 	/// VDate: ftime -> float days
-	override double as_double() const { return ((double)ftime)/ SECS_PER_DAY; }
+	override double as_double() const {
+		volatile double result = ((double)ftime) / SECS_PER_DAY; // avoid x87 returns 80 bit double
+		return result;
+	}
+
+	/// VDate: ftime -> int days
+	override int as_int() const {
+		return clip2int(trunc(as_double()));
+	}
 
 	/// VDate: 0 or !0
 	override bool as_bool() const { return ftime!=0; }
