@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b double parser class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VDOUBLE_H
 #define PA_VDOUBLE_H
 
-#define IDENT_PA_VDOUBLE_H "$Id: pa_vdouble.h,v 1.71 2020/12/15 17:10:39 moko Exp $"
+#define IDENT_PA_VDOUBLE_H "$Id: pa_vdouble.h,v 1.77 2024/11/04 03:53:25 moko Exp $"
 
 // includes
 
@@ -40,7 +40,7 @@
 extern Methoded* double_class;
 
 /// value of type 'double'. implemented with @c double
-class VDouble: public VStateless_object {
+class VDouble: public VSimple_stateless_object {
 public: // Value
 
 	override const char* type() const { return VDOUBLE_TYPE; }
@@ -63,7 +63,7 @@ public: // Value
 	override int as_int() const { return get_int(); }
 	/// VDouble: 0 or !0
 	override bool as_bool() const { return fdouble!=0; }
-	/// VInt: json-string
+	/// VDouble: json-string
 	override const String* get_json_string(Json_options&) { return get_string(); }
 
 public: // usage
@@ -73,7 +73,7 @@ public: // usage
 			throw Exception("number.format", 0, pa_isnan(adouble) ? "invalid number (double)" : "out of range (double)");
 	}
 
-	int get_int() const { return (int)trunc(fdouble); }
+	int get_int() const { return clip2int(trunc(fdouble)); }
 	double get_double() const { return fdouble; }
 
 	void inc(double increment) { fdouble+=increment; }
@@ -86,10 +86,10 @@ public: // usage
 		fdouble/=d; 
 	}
 	
-	void mod(int d) {
+	void mod(double d) {
 		if(d == 0)
 			throw Exception("number.zerodivision", 0, "Modulus by zero");
-		fdouble=((int)fdouble)%d;
+		fdouble=fmod(fdouble, d);
 	}
 
 private:
