@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b file parser type decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VFILE_H
 #define PA_VFILE_H
 
-#define IDENT_PA_VFILE_H "$Id: pa_vfile.h,v 1.85 2020/12/15 17:10:40 moko Exp $"
+#define IDENT_PA_VFILE_H "$Id: pa_vfile.h,v 1.88 2024/11/04 03:53:25 moko Exp $"
 
 // include
 
@@ -54,8 +54,7 @@ public: // Value
 	override Value& as_expr_result() { return VBool::get(true); }
 
 	/// VFile: this
-	override VFile* as_vfile(String::Language /*lang*/, 
-		const Request_charsets* /*charsets*/) { return this; }
+	override VFile* as_vfile() { return this; }
 
 	/// VFile: json-string
 	override const String* get_json_string(Json_options& options);
