@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b hash parser type decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VHASH_H
 #define PA_VHASH_H
 
-#define IDENT_PA_VHASH_H "$Id: pa_vhash.h,v 1.82 2020/12/15 17:10:40 moko Exp $"
+#define IDENT_PA_VHASH_H "$Id: pa_vhash.h,v 1.87 2024/11/04 03:53:26 moko Exp $"
 
 #include "classes.h"
 #include "pa_value.h"
@@ -34,6 +34,7 @@ public: // usage
 	virtual HashStringValue& hash()=0;
 	virtual void set_default(Value* adefault)=0;
 	virtual Value* get_default()=0;
+	virtual void add(Value* avalue)=0;
 };
 
 
@@ -72,7 +73,7 @@ public: // value
 		// default value
 		return get_default();
 	}
-	
+
 #ifdef FEATURE_GET_ELEMENT4CALL
 	override Value* get_element4call(const String& aname) {
 		// $method first
@@ -84,10 +85,13 @@ public: // value
 			return result;
 
 		// default value
-		return get_default();
+		if(Value* result=get_default())
+			return result;
+
+		return bark("%s method not found", &aname);
 	}
 #endif
-	
+
 	/// VHash: (key)=value
 	override const VJunction* put_element(const String& aname, Value* avalue) {
 		if(SYMBOLS_EQ(aname,_DEFAULT_SYMBOL))
@@ -109,6 +113,7 @@ public: // usage
 	override HashStringValue& hash() { return fhash; }
 	override void set_default(Value* adefault) { _default=adefault; }
 	override Value* get_default() { return _default; }
+	override void add(Value* avalue) { fhash.put(pa_uitoa(fhash.count()), avalue); }
 
 	void extract_default();
 
@@ -181,6 +186,7 @@ public: // usage
 	override HashStringValue& hash() { return *fhash; }
 	override void set_default(Value*) { }
 	override Value* get_default() { return 0; }
+	override void add(Value* avalue) { fhash->put(pa_uitoa(fhash->count()), avalue); }
 
 private:
 
