@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b int parser class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VINT_H
 #define PA_VINT_H
 
-#define IDENT_PA_VINT_H "$Id: pa_vint.h,v 1.55 2020/12/15 17:10:41 moko Exp $"
+#define IDENT_PA_VINT_H "$Id: pa_vint.h,v 1.61 2024/11/04 03:53:26 moko Exp $"
 
 // include
 
@@ -23,7 +23,7 @@
 extern Methoded* int_class;
 
 /// value of type 'int'. implemented with @c int
-class VInt: public VStateless_object {
+class VInt: public VSimple_stateless_object {
 public: // Value
 
 	override const char* type() const { return VINT_TYPE; }
@@ -58,12 +58,12 @@ public: // usage
 
 	void inc(int increment) { finteger+=increment; }
 	
-	void mul(double k) { finteger=(int)(finteger*k); }
+	void mul(double k) { finteger=clip2int(finteger*k); }
 	
 	void div(double d) {
 		if(d == 0)
 			throw Exception("number.zerodivision", 0, "Division by zero");
-		finteger=(int)(finteger/d); 
+		finteger=clip2int(finteger/d);
 	}
 	
 	void mod(int d) {
