@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b method_frame write context
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VMETHOD_FRAME_H
 #define PA_VMETHOD_FRAME_H
 
-#define IDENT_PA_VMETHOD_FRAME_H "$Id: pa_vmethod_frame.h,v 1.127 2020/12/15 17:10:42 moko Exp $"
+#define IDENT_PA_VMETHOD_FRAME_H "$Id: pa_vmethod_frame.h,v 1.144 2024/12/11 23:53:49 moko Exp $"
 
 #include "pa_symbols.h"
 #include "pa_wcontext.h"
@@ -26,7 +26,7 @@ class Request;
 
 class MethodParams {
 public:
-	MethodParams() : felements(0), fused(0) {}
+	MethodParams() : felements(0), fsize(0) {}
 
 #ifdef USE_DESTRUCTORS
 	~MethodParams() {
@@ -41,10 +41,10 @@ public:
 
 	void store_params(Value **params, size_t count) {
 		felements=params;
-		fused=count;
+		fsize=count;
 	}
 
-	inline size_t count() const { return fused; }
+	inline size_t count() const { return fsize; }
 
 	inline Value& get(size_t index) const {
 		assert(index<count());
@@ -58,7 +58,7 @@ public:
 		Value& value=get(index);
 		if(value.get_junction())
 			return value;
-		throw Exception(PARSER_RUNTIME, 0, "%s (parameter #%d)", msg, 1+index);
+		throw Exception(PARSER_RUNTIME, 0, "%s (parameter #%d is '%s')", msg, 1+index, value.type());
 	}
 
 	/// handy value-is-not-a-junction ensurer
@@ -66,7 +66,7 @@ public:
 		Value& value=get(index);
 		if(!value.get_junction())
 			return value;
-		throw Exception(PARSER_RUNTIME, 0, "%s (parameter #%d)", msg, 1+index);
+		throw Exception(PARSER_RUNTIME, 0, "%s (parameter #%d is '%s')", msg, 1+index, value.type());
 	}
 
 	/// handy is-value-a-junction ensurer or can be auto-processed
@@ -76,7 +76,7 @@ public:
 			return value;
 		if(value.get_junction())
 			return value;
-		throw Exception(PARSER_RUNTIME, 0, "%s (parameter #%d)", msg, 1+index);
+		throw Exception(PARSER_RUNTIME, 0, "%s (parameter #%d is '%s')", msg, 1+index, value.type());
 	}
 
 	/// handy expression auto-processing to double
@@ -95,6 +95,23 @@ public:
 		return get_processed(value, msg, index, r).as_int();
 	}
 
+	/// handy param auto-processing to index
+	int as_index(int index, size_t count, Request& r) {
+		if(get(index).is_string()) {
+			const String& svalue=*get(index).get_string();
+			if(svalue == "last")
+				return count-1;
+			else if(svalue != "first")
+				throw Exception(PARSER_RUNTIME, &svalue, "index must be 'first', 'last' or expression");
+			return 0;
+		} else {
+			int result=as_int(index, "index must be 'first', 'last' or expression", r);
+			if(result < 0)
+				result+=count;
+			return result;
+		}
+	}
+
 	/// handy expression auto-processing to bool
 	bool as_bool(int index, const char* msg, Request& r) {
 		Value& value=get(index);
@@ -105,9 +122,17 @@ public:
 
 	/// handy string ensurer
 	const String& as_string(int index, const char* msg) {
-		return as_no_junction(index, msg).as_string();
+		if(const String *result=get(index).get_string())
+			return *result;
+		throw Exception(PARSER_RUNTIME, 0, "%s (parameter #%d is '%s')", msg, 1+index, get(index).type());
 	}
 
+	/// handy file name ensurer
+	const String& as_file_name(int index);
+
+	/// handy file name from string or file
+	const String& as_file_spec(int index);
+
 	/// handy hash ensurers
 	HashStringValue* as_hash(int index, const char* name=0);
 
@@ -117,7 +142,7 @@ public:
 private:
 
 	Value **felements;
-	size_t fused;
+	size_t fsize;
 
 	Value& get_processed(Value& value, const char* msg, int index, Request& r);
 
@@ -205,14 +230,15 @@ public: // Value
 
 	/// VParserMethodFrame: $result | parent get_string(=accumulated fstring)
 	override const String* get_string() {
-		// check the $result value
-		Value* result=get_result_variable();
-		// if we have one, return it's string value, else return as usual: accumulated fstring or fvalue
-		return result ? result->get_string() : WContext::get_string();
+		// if we have $result, return it's string value, else return as usual: accumulated fstring or fvalue
+		return my_result ? my_result->get_string() : WContext::get_string();
 	}
 
 	/// VParserMethodFrame: my or self_transparent or $caller
 	override Value* get_element(const String& aname) {
+		if(SYMBOLS_EQ(aname,RESULT_SYMBOL))
+			return my_result ? my_result : VVoid::get();
+
 		if(SYMBOLS_EQ(aname,CALLER_SYMBOL))
 			return get_caller_wrapper();
 
@@ -230,6 +256,19 @@ public: // Value
 
 	/// VParserMethodFrame: my or self_transparent
 	override const VJunction* put_element(const String& aname, Value* avalue) {
+		if(SYMBOLS_EQ(aname,RESULT_SYMBOL)){
+			my_result=avalue;
+#ifdef OPTIMIZE_RESULT
+			// This check is only for maintaining consistency. Even if we change the mode from RO_USE_WCONTEXT, it will not work because
+			// CO_WITHOUT_WCONTEXT is also active. In this mode writes go directly to the parent context and result() is never called.
+			// If we also change CO_WITHOUT_WCONTEXT, the current method call will still continue writing to the parent context and
+			// result() will not be called. Only subsequent method calls will use $result.
+			// The current behavior is more predictable: the first method call determines result_optimization, and subsequent calls never change it.
+			if(method.result_optimization==Method::RO_UNKNOWN)
+				((Method *)&method)->result_optimization=Method::RO_USE_RESULT;
+#endif
+			return 0;
+		}
 		if(my.put_replaced(aname, avalue))
 			return 0;
 		return self().put_element(aname, avalue);
@@ -250,18 +289,16 @@ public: // WContext
 	}
 
 	override ValueRef result() {
-		// check the $result value
-		Value* result_value=get_result_variable();
-		// if we have one, return it, else return as usual: accumulated fstring or fvalue
-		if(result_value){
-#ifdef OPTIMIZE_RESULT
-			((Method *)&method)->result_optimization=Method::RO_USE_RESULT;
-#endif
-			return result_value;
-		}
+		// if we have $result, return it, else return as usual: accumulated fstring or fvalue
+		if(my_result)
+			return my_result;
 #ifdef OPTIMIZE_RESULT
 		if(method.result_optimization==Method::RO_USE_RESULT)
 			return VVoid::get();
+
+		// Due to call optimization, the following code is called only once.
+		// CO_WITHOUT_WCONTEXT means subsequent writes will be to the parent context, and the result() won't be called.
+
 		((Method *)&method)->result_optimization=Method::RO_USE_WCONTEXT;
 #ifdef OPTIMIZE_CALL // nested as CO_WITHOUT_WCONTEXT assumes that $result not used
 		((Method *)&method)->call_optimization=Method::CO_WITHOUT_WCONTEXT;
@@ -273,6 +310,7 @@ public: // WContext
 public: // usage
 
 	HashString<Value*> my; // public for ^stack[]
+	Value* my_result;
 
 	VParserMethodFrame(const Method& amethod, VMethodFrame *acaller, Value& aself);
 
@@ -281,42 +319,73 @@ public: // usage
 		size_t i=0;
 
 		if(count>param_count){
-			if(method.extra_params){
-				for(; i<param_count; i++) {
-					const String& fname=*(*method.params_names)[i];
-					set_my_variable(fname, *params[i]);
-				}
 
+			for(; i<param_count; i++) {
+				const String& fname=*(*method.params_names)[i];
+				set_my_variable(fname, params[i]);
+			}
+
+			if(method.extra_params){
 				VHash& vargs=*new VHash();
 				HashStringValue& args = vargs.hash();
 
 				for(; i<count; i++) {
-					args.put(format(args.count(), 0), params[i]);
+					args.put(pa_uitoa(args.count()), params[i]);
 				}
 
-				set_my_variable(*method.extra_params, vargs);
-				return;
+				set_my_variable(*method.extra_params, &vargs);
+			} else if(method.named_params){
+				if(count!=param_count+1)
+					throw Exception(PARSER_RUNTIME, method.name, "method of '%s' accepts maximum %d parameter(s) (%d present)", self().type(), param_count+1, count);
+
+				HashStringValue* named_args = params[i]->as_hash("named parameter");
+				size_t named_count=method.named_params->count();
+ 				for(i=0; i<named_count; i++) {
+					const String& fname=*(*method.named_params)[i];
+					Value *arg=named_args ? named_args->get(fname) : NULL;
+					set_my_variable(fname, arg ? arg : VVoid::get());
+				}
 			} else
 				throw Exception(PARSER_RUNTIME, method.name, "method of '%s' accepts maximum %d parameter(s) (%d present)", self().type(), param_count, count);
-		}
+		} else {
 
-		for(; i<count; i++) {
-			const String& fname=*(*method.params_names)[i];
-			set_my_variable(fname, *params[i]);
-		}
+			for(; i<count; i++) {
+				const String& fname=*(*method.params_names)[i];
+				set_my_variable(fname, params[i]);
+			}
 
-		for(; i<param_count; i++) {
-			const String& fname=*(*method.params_names)[i];
-			my.put(fname, VVoid::get());
+			for(; i<param_count; i++) {
+				const String& fname=*(*method.params_names)[i];
+				set_my_variable(fname, VVoid::get());
+			}
+
+			if(method.extra_params){
+				set_my_variable(*method.extra_params, VVoid::get());
+			} else if(method.named_params){
+				size_t named_count=method.named_params->count();
+				for(i=0; i<named_count; i++) {
+					const String& fname=*(*method.named_params)[i];
+					set_my_variable(fname, VVoid::get());
+				}
+			}
 		}
 	}
 
 	void empty_params(){
 		size_t param_count=method.params_count;
 		if(param_count>0){
-			my.put(*(*method.params_names)[0], VString::empty());
+			set_my_variable(*(*method.params_names)[0], VString::empty());
 			for(size_t i=1; i<param_count; i++)
-				my.put(*(*method.params_names)[i], VVoid::get());
+				set_my_variable(*(*method.params_names)[i], VVoid::get());
+		}
+		if(method.extra_params){
+			set_my_variable(*method.extra_params, VVoid::get());
+		} else if(method.named_params){
+			size_t named_count=method.named_params->count();
+			for(size_t i=0; i<named_count; i++) {
+				const String& fname=*(*method.named_params)[i];
+				set_my_variable(fname, VVoid::get());
+			}
 		}
 	}
 
@@ -324,12 +393,17 @@ public: // usage
 
 protected:
 
-	void set_my_variable(const String& fname, Value& value) {
-		my.put(fname, &value); // remember param
+	inline void set_my_variable(const String& aname, Value* value) {
+		if(SYMBOLS_EQ(aname,RESULT_SYMBOL)){
+			my_result=value;
+#ifdef OPTIMIZE_RESULT
+			((Method *)&method)->result_optimization=Method::RO_USE_RESULT;
+#endif
+			return;
+		}
+		my.put(aname, value); // remember param
 	}
 
-	Value* get_result_variable();
-
 	Value* get_caller_wrapper();
 
 };
@@ -339,7 +413,7 @@ class VLocalParserMethodFrame: public VParserMethodFrame {
 public: // Value
 
 	override const VJunction* put_element(const String& aname, Value* avalue){
-		set_my_variable(aname, *avalue);
+		set_my_variable(aname, avalue);
 		return 0;
 	}
 
@@ -395,10 +469,10 @@ public:
 		action;										\
 	} else {										\
 		if((method).all_vars_local){							\
-			VExpressionFrame<VLocalParserMethodFrame> frame(method, caller, self);	\
+			VLocalParserMethodFrame frame(method, caller, self);			\
 			action;									\
 		} else {									\
-			VExpressionFrame<VParserMethodFrame> frame(method, caller, self);	\
+			VParserMethodFrame frame(method, caller, self);				\
 			action;									\
 		}										\
 	}
