@@ -1,14 +1,14 @@
 /**	@file
 	Parser: @b object class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VOBJECT_H
 #define PA_VOBJECT_H
 
-#define IDENT_PA_VOBJECT_H "$Id: pa_vobject.h,v 1.68 2020/12/15 17:10:42 moko Exp $"
+#define IDENT_PA_VOBJECT_H "$Id: pa_vobject.h,v 1.72 2024/11/04 03:53:26 moko Exp $"
 
 // includes
 
@@ -40,7 +40,7 @@ class VObject: public Value {
 public: // Value
 	
 	const char* type() const { return fclass.type(); }
-	override Value* as(const char* atype);
+	override bool is(const char* atype);
 
 	/// VObject: fclass
 	override VStateless_class *get_class() { return &fclass; }
@@ -50,7 +50,7 @@ public: // Value
 	override int as_int() const;
 	override double as_double() const;
 	override bool as_bool() const;
-	override VFile* as_vfile(String::Language lang, const Request_charsets *charsets=0);
+	override VFile* as_vfile();
 	
 	override HashStringValue* get_hash();
 	override Table *get_table();
