@@ -1,14 +1,14 @@
 /** @file
 	Parser: stateless class decls.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VSTATELESS_CLASS_H
 #define PA_VSTATELESS_CLASS_H
 
-#define IDENT_PA_VSTATELESS_CLASS_H "$Id: pa_vstateless_class.h,v 1.94 2021/01/02 23:01:11 moko Exp $"
+#define IDENT_PA_VSTATELESS_CLASS_H "$Id: pa_vstateless_class.h,v 1.99 2024/11/04 03:53:26 moko Exp $"
 
 // include
 
@@ -64,10 +64,19 @@ public: // Value
 	/// get_element with aself for VObject junctions
 	virtual Value* get_element(Value& aself, const String& aname);
 
+#ifdef FEATURE_GET_ELEMENT4CALL
+	/// same as get_element, but with proper error reporting
+	override Value* get_element4call(const String& aname) {
+		if(Value* result=get_element(*this, aname))
+			return result;
+		return bark("%s method not found", &aname);
+	}
+#endif
+
 	override const VJunction* put_element(const String& aname, Value* avalue) { return put_element(*this, aname, avalue); }
 	/// put_element with aself for VObject junctions
 	virtual const VJunction* put_element(Value& aself, const String& aname, Value* /*avalue*/) {
-		aself.bark("element can not be stored to %s", &aname); 
+		aself.bark("element cannot be stored into %s", &aname); 
 		return 0;
 	}
 
