@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b stateless_object class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VSTATELESS_OBJECT_H
 #define PA_VSTATELESS_OBJECT_H
 
-#define IDENT_PA_VSTATELESS_OBJECT_H "$Id: pa_vstateless_object.h,v 1.44 2020/12/15 17:10:43 moko Exp $"
+#define IDENT_PA_VSTATELESS_OBJECT_H "$Id: pa_vstateless_object.h,v 1.48 2024/11/04 03:53:26 moko Exp $"
 
 // include
 
@@ -21,12 +21,22 @@
 */
 class VStateless_object: public Value {
 public: // Value
-	
+
 	/// VStateless_object: class_transparent
 	override Value* get_element(const String& aname) {
+		// $methods (CLASS, CLASS_NAME only if no OPTIMIZE_BYTECODE_GET_ELEMENT__SPECIAL)
 		return get_class()->get_element(*this, aname);
 	}
 
+#ifdef FEATURE_GET_ELEMENT4CALL
+	/// same as get_element, but with proper error reporting
+	override Value* get_element4call(const String& aname) {
+		if(Value* result=get_class()->get_element(*this, aname))
+			return result;
+		return bark("%s method not found", &aname);
+	}
+#endif
+
 	/// VStateless_object: class_transparent
 	override const VJunction* put_element(const String& aname, Value* avalue) { 
 		return get_class()->put_element(*this, aname, avalue);
@@ -44,4 +54,18 @@ public: // Value
 
 };
 
+class VSimple_stateless_object: public VStateless_object {
+public: // Value
+
+	/// VSimple_stateless_object: class_transparent
+	override Value* get_element(const String& aname) {
+		// $methods (CLASS, CLASS_NAME only if no OPTIMIZE_BYTECODE_GET_ELEMENT__SPECIAL)
+		if(Value* result=get_class()->get_element(*this, aname))
+			return result;
+
+		// bad $type.field
+		return Value::get_element(aname);
+	}
+};
+
 #endif
