@@ -1,14 +1,14 @@
 /**	@file
 	Parser: @b string parser class decl.
 
-	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
-	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
+	Copyright (c) 2001-2024 Art. Lebedev Studio (http://www.artlebedev.com)
+	Authors: Konstantin Morshnev <moko@design.ru>, Alexandr Petrosian <paf@design.ru>
 */
 
 #ifndef PA_VSTRING_H
 #define PA_VSTRING_H
 
-#define IDENT_PA_VSTRING_H "$Id: pa_vstring.h,v 1.75 2020/12/15 17:10:43 moko Exp $"
+#define IDENT_PA_VSTRING_H "$Id: pa_vstring.h,v 1.81 2024/11/04 03:53:26 moko Exp $"
 
 // includes
 
@@ -54,30 +54,21 @@ public: // Value
 	/// VString: $method
 	override Value* get_element(const String& aname) {
 #if !defined(FEATURE_GET_ELEMENT4CALL) || !defined(OPTIMIZE_BYTECODE_GET_ELEMENT__SPECIAL)
-		// $method, CLASS, CLASS_NAME
+		// CLASS, CLASS_NAME and normally hidden $method
 		if(Value* result=VStateless_object::get_element(aname))
 			return result;
 #endif
-		// empty or whitespace string is void compatible
+		// void, empty or whitespace string are hash compatible
 		if (fstring->is_empty() || fstring->trim().is_empty())
 			return 0;
 
 		// bad $string.field
-#ifdef FEATURE_GET_ELEMENT4CALL
 		return Value::get_element(aname);
 	}
 
-	override Value* get_element4call(const String& aname) {
-		// $method
-		if(Value* result=VStateless_object::get_element(aname))
-			return result;
-#endif
-		return bark("%s method not found", &aname);
-	}
-
 public: // usage
 
-	VString(): fstring(new String) {}
+	VString(): fstring(&String::Empty) {}
 	VString(const String& avalue): fstring(&avalue) {}
 
 	const String& string() const { return *fstring; }
